@@ -4,4 +4,6 @@ from .grids import *
 from .ckdnearest import *
 from .odprocess import *
 from .preprocess import *
-__version__ = '0.1.1'
\ No newline at end of file
+from .bikedata import *
+from .taxigps import *
+__version__ = '0.1.4'
\ No newline at end of file
